@@ -8,9 +8,9 @@
 #' @param test A character string to specify the name of the test. Default is \code{"fisher"}. \code{"t"} is available for the fixed effects model.
 #' @param threshold A numerical value that specify the threshold for the \code{"clustermass"} multiple comparisons procedure. If it is a vector each value will be associated to an effect. If it is scalar the same threshold will be used for each test. Default value is \code{NULL} and will compute a threshold based on the 0.95 quantile of the choosen test statistic.
 #' @param aggr_FUN A function used as mass function. It should aggregate the statistics of a cluster into one scalar. Default is the sum of squares fot t statistic and sum for F statistic.
-#' @param multcomp A vector of character defining the methods of multiple comparisons to compute. Default is \code{"clustermass"}, and the additional options are available : \code{"tfce"},\code{"bonferroni"}, \code{"holm"}, \code{"troendle"} and \code{"benjamini_hochberg"}.
+#' @param multcomp A vector of character defining the methods of multiple comparisons to compute. Default is \code{"clustermass"}, and the additional options are available : \code{"tfce"},\code{"bonferroni"}, \code{"holm"}, \code{"troendle"}, \code{"minP"} and \code{"benjamini_hochberg"}.
 #' @param ... Futher arguments, see details.
-#' @return A list containing : a table of the clusters, or a \code{multcomp} object for the other multiple comparison procedures. Use the \link{plot.clusterlm} method to have a quick overview of the results.
+#' @return A \code{clusterlm} object. Use the \link{plot.clusterlm} or \link{summary.clusterlm} method to see results of the tests.
 #' @details
 #' The random effects model is only avaible with a F statistic.\cr
 #'
@@ -23,7 +23,7 @@
 #' \code{return_distribution = FALSE} : return the permutation distribution of the statistics. Warnings : return one high dimentional matrices (number of test times number of permutation) for each test.\cr
 #' \code{coding_sum} : a logical defining the coding of the design matrix to \code{contr.sum}: set by default to \code{TRUE} for ANOVA (when the argument \code{test} is \code{"fisher"} ) to tests main effects and is set to \code{FALSE} when \code{test} is \code{"t"}.  If \code{coding_sum} is set to \code{FALSE} the design matrix is computed with the coding defined in the dataframe and the tests of simple effets are possible with a coding of the dataframe set to \code{contr.treatment}. \cr
 #'
-#' @seealso \code{\link{plot.clusterlm}}
+#' @seealso \code{\link{plot.clusterlm}} \code{\link{summary.clusterlm}}
 #'
 #'@references
 #'Maris, E., & Oostenveld, R. (2007). Nonparametric statistical testing of EEG-and MEG-data. Journal of neuroscience methods, 164(1), 177-190.
@@ -132,6 +132,9 @@ clusterlm <- function(formula, data=NULL, np = 5000, method = NULL, test = "fish
            "fisher" = {dotargs$coding_sum = T})
   }
 
+  multcomp <- match.arg(multcomp, c("clustermass", "tfce", "troendle","minP" , "bonferroni", "holm", "benjamini_hochberg"),
+                        several.ok = T)
+
   ###switch fix effet
   if (is.null(indError)) {
     result <- clusterlm_fix( formula = formula, data = data, method = method, test = test, np = np,
